@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2011-2012 Free Software Foundation, Inc.
+# Copyright (C) 2011-2013 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # even when the Automake-generated parallel testsuite harness failed.
 # See automake bug#9245.
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_OUTPUT
@@ -42,21 +42,16 @@ $AUTOMAKE -a
 
 ./configure
 
-# Some make implementations don't grok the '-j' option.
-$MAKE -j1 || Exit 77
+$MAKE -j1 || skip_ "'$MAKE' doesn't support the -j option"
 
 for j in '' -j1 -j2; do
-  $MAKE $j check && Exit 1
-  TESTS=foo.test $MAKE $j -e check && Exit 1
-  if test x"$am_parallel_tests" = x"yes"; then
-    $MAKE $j recheck && Exit 1
-    TEST_LOGS=foo.log $MAKE $j -e check && Exit 1
-    rm -f test-suite.log
-    $MAKE $j test-suite.log && Exit 1
-    test -f test-suite.log || Exit 1
-  else
-    : # For shells with buggy 'set -e'.
-  fi
+  $MAKE $j check && exit 1
+  run_make -e FAIL -- $j TESTS=foo.test check
+  $MAKE $j recheck && exit 1
+  run_make -e FAIL -- $j TEST_LOGS=foo.log check
+  rm -f test-suite.log
+  run_make -e FAIL $j test-suite.log
+  test -f test-suite.log || exit 1
 done
 
 :
