@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2001-2012 Free Software Foundation, Inc.
+# Copyright (C) 2001-2013 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 # Test for bug with conditional library.
 # From Harlan Stenn.
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_RANLIB
@@ -40,5 +40,5 @@ END
 $ACLOCAL
 $AUTOMAKE
 
-$FGREP librsaref.a.c Makefile.in && Exit 1
-Exit 0
+$FGREP librsaref.a.c Makefile.in && exit 1
+exit 0
