@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2000-2012 Free Software Foundation, Inc.
+# Copyright (C) 2000-2013 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
 # Test to make sure that 'automake --force-missing' works.
 
-. ./defs || Exit 1
+. test-init.sh
 
 rm -f install-sh
 
@@ -29,6 +29,6 @@ $AUTOMAKE --add-missing --force-missing
 
 ls -l install-sh
 test -f install-sh
-grep zot install-sh && Exit 1
+grep zot install-sh && exit 1
 
 :
